==> FHLBBS-5.3.tgz: php/talk.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","caller");
define("USRRECLENGTH",256);
 $now=date("m/d/Y H:i:s D");
 $tyn=(int) $_REQUEST["YN"];
 if ($tyn==1) //n
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   $genbuf=sethomefile($caller,"talk_data");
   echo "<META HTTP-EQUIV=\"Refresh\" Content=\"10\">";
   echo"<center>$now<hr><font color=\"red\"> $caller</font>  </center>\n";
   if (is_file($genbuf))
   {
 	$gen1=sethomefile($caller,"talk_call");
 	$gen2=sethomefile($caller,"talk_req");
        if (is_file($gen1)||is_file($gen2))
	{
		echo "<font color=\"red\">٨SsuI</font>";
	}
        else
	{
   		$data=file($genbuf);
   		$cnt=count($data);
   		$cnt=$cnt-1;
   		$bg=$cnt-$TALKNUM;
   		if ($bg<0) $bg=0;
   		for ($i=$bg;$i<=$cnt;$i=$i+1)
       			echo "{$data[$i]}<br>\n";
	}
   }
   else
   {
	echo "<font color=\"red\">wgsuAثe٨So</font>";
   }
   echo"<hr><center><font color=\"blue\">$cuser->userid</font>  </center>";
   if (is_file($genbuf1))
   {   
   	$data=file($genbuf1);
   	$cnt=count($data);
   	$cnt=$cnt-1;
   	$bg=$cnt-$TALKNUM;
   	if ($bg<0) $bg=0;
   	for ($i=$bg;$i<=$cnt;$i=$i+1)
       		echo "{$data[$i]}<br>\n";
   }
   else
   {
	echo "<font color=\"red\">wgsuAثe٨So</font>";
   }
   die ("<br><hr>");
 }
 elseif ($tyn==2) //
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   if (($fp= fopen($genbuf1, "w")) === false)
        die("$genbuf1 OPEN ERROR!");
   fwrite($fp,"藍_Aڲ{bܦALkAѡI");
   fclose($fp);
   die ("wgڵFI");  
 }
 elseif ($tyn==3) //ѤAJ
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   if (($fp= fopen($genbuf1, "a")) === false)
        die("$genbuf1 OPEN ERROR!");
   $inp=$_REQUEST["word"];
   fwrite($fp,"{$inp}\n");
   fclose($fp);
   header("Location: /talk2.html");
   die("");
 }
 elseif ($tyn==4) //nD
 {
	//ˬdv
        if (!HAS_PERM(PERM_LOGINOK))
		die ("zT{|qLALkDʵo_ѡI");
        $caller= trim($_REQUEST["id"]);
        if (strcasecmp($caller,$cuser->userid)==0)
		die ("$caller ۤviHIsۤv!");
	$uid=searchuser($caller);
	if ($uid==0) die("SoӤHsbI");
	$xuser= new userrec;
        if ($fd = fopen($PASSWD_FILE, "r")) {
        	fseek($fd, USRRECLENGTH  * ($uid - 1), SEEK_SET);
        	$recmsg=fread($fd, USRRECLENGTH);
        	$xuser->unpack($recmsg);
        	if (strcasecmp($xuser->userid,$caller)==0)
		{
			if ($xuser->uflag & PAGER_FLAG ) die("ѥ\FI");
		}
		else
		{
			fclose($fd);
			die ("S $caller oӤHI");
		}
		fclose($fd);
        }
	else
		die ("KXɶ}ҿ~I");
        /*****屼ۤv¸*****/
 	$genbuf=sethomefile($cuser->userid,"talk_data");
 	if (is_file($genbuf)) die("pIثebPHѤI");
	$genbuf=sethomefile($caller, "talk_req");
   	if (($fp= fopen($genbuf, "w")) === false)
        	die("$genbuf OPEN ERROR!");
   	fwrite($fp,"$cuser->userid");
   	fclose($fp);
        echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n window.open(\"/talk.html\",\"talk_window\",\"toolbar=no,width=600,height=450,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";

	die ("<center><a href=\"JavaScript:history.go(-1)\">IsA^W@</a></center>");
	
 }
 elseif ($tyn==5) //plain
 {
        $who= trim($_REQUEST["id"]);
	echo "<pre>";
	$genbuf=sethomefile($who, "plans");
                if (is_file($genbuf))
                        readfile($genbuf);
	echo "</pre><br><center>";
	die ("<a href=\"Javascript:history.go(-1)\">^W@</a></center>");
 }
 elseif ($tyn==6) //ݲѫeǳưʧ@
 {
 	$genbuf=sethomefile($cuser->userid,"talk_data");
 	if (is_file($genbuf)) unlink($genbuf);
   	header("Location: /talk.html");
	die("");
 }
 elseif ($tyn==7) //
 {
	$t1 = time();
   	$t2 = date("D M d H:i:s Y");
 	$gen=sethomefile($cuser->userid,"talk_data");
 	$gen1=sethomefile($caller,"talk_data");
	$filename2="M.{$t1}.A";
        $receiver=$cuser->userid;
        $filename1=sethomefile($receiver,$filename2);
        if (($fptr2 = fopen($filename1,"w"))===false)
                die ("S{$receiver}oӤHI<p>\n");
        $genbuf=sprintf("@: %s(%s)\n",$cuser->userid,$cuser->username);
            fwrite($fptr2,$genbuf);
	fwrite($fptr2,"D: ܰO ($caller)\n");
      	fwrite($fptr2,"ɶ: {$t2}\n\n");
      	fwrite($fptr2,"$caller o:\n");
        fwrite($fptr2,join ('', file ($gen1)));
      	fwrite($fptr2,"\n$cuser->userid o:\n");
        fwrite($fptr2,join ('', file ($gen)));
	fclose($fptr2);
	$postfile=new dirrec;
	$postfile->filename=$filename2;
   	$postfile->owner="[..]";
   	$postfile->title="ܰO ($caller)";
   	/*** gY ***/
   	$postfile->date=date("m/d");
   	if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
        $buf1=sethomedir($receiver);
   	$numposts = (int) filesize($buf1)/$dirlength;
   	$postfile->substitute_record($buf1,$numposts+1);
	$genbuf1=sethomefile($cuser->userid,"talk_data");
   	if (($fp= fopen($genbuf1, "a")) === false)
        	die("$genbuf1 OPEN ERROR!");
   	fwrite($fp,"<font color=\"red\">$cuser->userid wg}FI</font>\n");
   	fclose($fp);
	 echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n parent.window.close() </script>";
	die("");
 }
 elseif ($tyn==8) //eT
 {
   	 $t2 = date("H:i:s");
	 $caller= trim($_REQUEST["id"]);
	 $genbuf=sethomefile($caller,"page_data");
	  if (($fp = fopen($genbuf,"a"))===false)
                die ("S{$caller}oӤHI<p>\n");
	  $inp=$_REQUEST["word"];
   	  fwrite($fp,"<font color=\"blue\">[{$t2}]</font><font color=\"red\">{$cuser->userid}: {$inp}</font> <a href=\"/php/talk.php?YN=10&id={$cuser->userid}\">^T</a>\n");
	  fclose($fp);
	die ("<center><a href=\"JavaScript:history.go(-1)\">oeA^W@</a></center>");
 }
 elseif ($tyn==9) //ŪT
 {
	 $genbuf=sethomefile($cuser->userid,"pager_data");
	 $data=file($genbuf);
         $cnt=count($data);
         $cnt=$cnt-1;
         for ($i=0;$i<=$cnt;$i=$i+1)
                  echo "{$data[$i]}<br>\n";
	 unlink($genbuf);
	 die("");
 }
 elseif ($tyn==10) //}lT
 {
  $caller= trim($_REQUEST["id"]);
  if (!HAS_PERM(PERM_LOGINOK))
		die ("zT{|qLALkDʵoT!");
  echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=big5\">\n";
  echo "<form method=\"post\" action=\"/php/talk.php\">\n";
  echo "<input type=\"hidden\" name=\"YN\" value=\"8\">\n";
  echo "<input type=\"hidden\" name=\"id\" value=\"{$caller}\">\n";
  echo " $caller TG";
  echo "<input type=\"text\" name=\"word\" size=40>\n";
  die ("<input type=\"submit\" name=\"sub1\" value=\"eX\">\n");
 }

 $genbuf=sethomefile($cuser->userid,"talk_call");
 $req=file($genbuf);
 $caller=trim($req[0]);
 unlink($genbuf);
 echo "<center><font size=+2>";
 echo "$cuser->userid zn!  $caller QnPz talk C<br>";
 echo "<a href=\"/php/talk.php?YN=6\">nL</a>\n";
 echo "<a href=\"/php/talk.php?YN=2\">nL</a>\n";
 echo "</font></center>";
?>

==> FHLBBS-5.4.tgz: php/talk.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","caller");
define("USRRECLENGTH",256);
 $now=date("m/d/Y H:i:s D");
 $tyn=(int) $_REQUEST["YN"];
 if ($tyn==1) //n
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   $genbuf=sethomefile($caller,"talk_data");
   echo "<META HTTP-EQUIV=\"Refresh\" Content=\"10\">";
   echo"<center>$now<hr><font color=\"red\"> $caller</font>  </center>\n";
   if (is_file($genbuf))
   {
 	$gen1=sethomefile($caller,"talk_call");
 	$gen2=sethomefile($caller,"talk_req");
        if (is_file($gen1)||is_file($gen2))
	{
		echo "<font color=\"red\">٨SsuI</font>";
	}
        else
	{
   		$data=file($genbuf);
   		$cnt=count($data);
   		$cnt=$cnt-1;
   		$bg=$cnt-$TALKNUM;
   		if ($bg<0) $bg=0;
   		for ($i=$bg;$i<=$cnt;$i=$i+1)
       			echo "{$data[$i]}<br>\n";
	}
   }
   else
   {
	echo "<font color=\"red\">wgsuAثe٨So</font>";
   }
   echo"<hr><center><font color=\"blue\">$cuser->userid</font>  </center>";
   if (is_file($genbuf1))
   {   
   	$data=file($genbuf1);
   	$cnt=count($data);
   	$cnt=$cnt-1;
   	$bg=$cnt-$TALKNUM;
   	if ($bg<0) $bg=0;
   	for ($i=$bg;$i<=$cnt;$i=$i+1)
       		echo "{$data[$i]}<br>\n";
   }
   else
   {
	echo "<font color=\"red\">wgsuAثe٨So</font>";
   }
   die ("<br><hr>");
 }
 elseif ($tyn==2) //
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   if (($fp= fopen($genbuf1, "w")) === false)
        die("$genbuf1 OPEN ERROR!");
   fwrite($fp,"藍_Aڲ{bܦALkAѡI");
   fclose($fp);
   die ("wgڵFI");  
 }
 elseif ($tyn==3) //ѤAJ
 {
   $genbuf1=sethomefile($cuser->userid,"talk_data");
   if (($fp= fopen($genbuf1, "a")) === false)
        die("$genbuf1 OPEN ERROR!");
   $inp=$_REQUEST["word"];
   fwrite($fp,"{$inp}\n");
   fclose($fp);
   header("Location: /talk2.html");
   die("");
 }
 elseif ($tyn==4) //nD
 {
	//ˬdv
        if (!HAS_PERM(PERM_LOGINOK))
		die ("zT{|qLALkDʵo_ѡI");
        $caller= trim($_REQUEST["id"]);
        if (strcasecmp($caller,$cuser->userid)==0)
		die ("$caller ۤviHIsۤv!");
	$uid=searchuser($caller);
	if ($uid==0) die("SoӤHsbI");
	$xuser= new userrec;
        if ($fd = fopen($PASSWD_FILE, "r")) {
        	fseek($fd, USRRECLENGTH  * ($uid - 1), SEEK_SET);
        	$recmsg=fread($fd, USRRECLENGTH);
        	$xuser->unpack($recmsg);
        	if (strcasecmp($xuser->userid,$caller)==0)
		{
			if ($xuser->uflag & PAGER_FLAG ) die("ѥ\FI");
		}
		else
		{
			fclose($fd);
			die ("S $caller oӤHI");
		}
		fclose($fd);
        }
	else
		die ("KXɶ}ҿ~I");
        /*****屼ۤv¸*****/
 	$genbuf=sethomefile($cuser->userid,"talk_data");
 	if (is_file($genbuf)) die("pIثebPHѤI");
	$genbuf=sethomefile($caller, "talk_req");
   	if (($fp= fopen($genbuf, "w")) === false)
        	die("$genbuf OPEN ERROR!");
   	fwrite($fp,"$cuser->userid");
   	fclose($fp);
        echo "<script LANGUAGE=\"JavaScript\">\n window.open(\"/talk.html\",\"talk_window\",\"toolbar=no,width=600,height=450,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";

	die ("<center><a href=\"JavaScript:history.go(-1)\">IsA^W@</a></center>");
	
 }
 elseif ($tyn==5) //plain
 {
        $who= trim($_REQUEST["id"]);
	echo "<pre>";
	$genbuf=sethomefile($who, "plans");
                if (is_file($genbuf))
                        readfile($genbuf);
	echo "</pre><br><center>";
	die ("<a href=\"Javascript:history.go(-1)\">^W@</a></center>");
 }
 elseif ($tyn==6) //ݲѫeǳưʧ@
 {
 	$genbuf=sethomefile($cuser->userid,"talk_data");
 	if (is_file($genbuf)) unlink($genbuf);
   	header("Location: /talk.html");
	die("");
 }
 elseif ($tyn==7) //
 {
	$t1 = time();
   	$t2 = date("D M d H:i:s Y");
 	$gen=sethomefile($cuser->userid,"talk_data");
 	$gen1=sethomefile($caller,"talk_data");
	$filename2="M.{$t1}.A";
        $receiver=$cuser->userid;
        $filename1=sethomefile($receiver,$filename2);
        if (($fptr2 = fopen($filename1,"w"))===false)
                die ("S{$receiver}oӤHI<p>\n");
        $genbuf=sprintf("@: %s(%s)\n",$cuser->userid,$cuser->username);
            fwrite($fptr2,$genbuf);
	fwrite($fptr2,"D: ܰO ($caller)\n");
      	fwrite($fptr2,"ɶ: {$t2}\n\n");
      	fwrite($fptr2,"$caller o:\n");
        fwrite($fptr2,join ('', file ($gen1)));
      	fwrite($fptr2,"\n$cuser->userid o:\n");
        fwrite($fptr2,join ('', file ($gen)));
	fclose($fptr2);
	$postfile=new dirrec;
	$postfile->filename=$filename2;
   	$postfile->owner="[..]";
   	$postfile->title="ܰO ($caller)";
   	/*** gY ***/
   	$postfile->date=date("m/d");
   	if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
        $buf1=sethomedir($receiver);
   	$numposts = (int) filesize($buf1)/$dirlength;
   	$postfile->substitute_record($buf1,$numposts+1);
	$genbuf1=sethomefile($cuser->userid,"talk_data");
   	if (($fp= fopen($genbuf1, "a")) === false)
        	die("$genbuf1 OPEN ERROR!");
   	fwrite($fp,"<font color=\"red\">$cuser->userid wg}FI</font>\n");
   	fclose($fp);
	 echo "<script LANGUAGE=\"JavaScript\">\n parent.window.close() </script>";
	die("");
 }
 elseif ($tyn==8) //eT
 {
   	 $t2 = date("H:i:s");
	 $caller= trim($_REQUEST["id"]);
	 $genbuf=sethomefile($caller,"page_data");
	  if (($fp = fopen($genbuf,"a"))===false)
                die ("S{$caller}oӤHI<p>\n");
	  $inp=$_REQUEST["word"];
   	  fwrite($fp,"<font color=\"blue\">[{$t2}]</font><font color=\"red\">{$cuser->userid}: {$inp}</font> <a href=\"/php/talk.php?YN=10&id={$cuser->userid}\">^T</a>\n");
	  fclose($fp);
	die ("<center><a href=\"JavaScript:history.go(-1)\">oeA^W@</a></center>");
 }
 elseif ($tyn==9) //ŪT
 {
	 $genbuf=sethomefile($cuser->userid,"pager_data");
	 $data=file($genbuf);
         $cnt=count($data);
         $cnt=$cnt-1;
         for ($i=0;$i<=$cnt;$i=$i+1)
                  echo "{$data[$i]}<br>\n";
	 unlink($genbuf);
	 die("");
 }
 elseif ($tyn==10) //}lT
 {
  $caller= trim($_REQUEST["id"]);
  if (!HAS_PERM(PERM_LOGINOK))
		die ("zT{|qLALkDʵoT!");
  echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=big5\">\n";
  echo "<form method=\"post\" action=\"/php/talk.php\">\n";
  echo "<input type=\"hidden\" name=\"YN\" value=\"8\">\n";
  echo "<input type=\"hidden\" name=\"id\" value=\"{$caller}\">\n";
  echo " $caller TG";
  echo "<input type=\"text\" name=\"word\" size=40>\n";
  die ("<input type=\"submit\" name=\"sub1\" value=\"eX\">\n");
 }

 $genbuf=sethomefile($cuser->userid,"talk_call");
 $req=file($genbuf);
 $caller=trim($req[0]);
 unlink($genbuf);
 echo "<center><font size=+2>";
 echo "$cuser->userid zn!  $caller QnPz talk C<br>";
 echo "<a href=\"/php/talk.php?YN=6\">nL</a>\n";
 echo "<a href=\"/php/talk.php?YN=2\">nL</a>\n";
 echo "</font></center>";
?>
